==============================================================
Save hierarchy to NDEx
==============================================================

Saving the hierarchy to `NDEx`_ provides other users easy access to the
hierarchy as well as enables access to view the hierarchy in `Cytoscape`_ or
the new `Cytoscape on the web`_ currently in development.

To read more on how to save hierarchy and its interactome to NDEx, see
`Uploading hierarchy to NDEx <https://cellmaps-generate-hierarchy.readthedocs.io/en/latest/usage.html#uploading-hierarchy-to-ndex>`__

.. _NDEx: https://www.ndexbio.org
.. _Cytoscape on the web: https://web-stage.cytoscape.org
.. _Cytoscape: https://cytoscape.org
